@@ -3,7 +3,9 @@ package File::Dir::Dumper::Scanner;
 use warnings;
 use strict;
 
-use base 'File::Dir::Dumper::Base';
+use 5.012;
+
+use parent 'File::Dir::Dumper::Base';
 
 use Carp;
 
@@ -32,11 +34,11 @@ hash-refs
 
 =head1 VERSION
 
-Version 0.0.8
+Version 0.0.9
 
 =cut
 
-our $VERSION = '0.0.8';
+our $VERSION = '0.0.9';
 
 =head1 SYNOPSIS
 
